@@ -26,6 +26,8 @@
 #include <KUrl>
 #include <KVBox>
 
+#include <QPointer>
+
 class KFileItemList;
 class PhononWidget;
 class PixmapViewer;
@@ -35,6 +37,10 @@ class QString;
 class QLabel;
 class QScrollArea;
 
+namespace KIO {
+    class PreviewJob;
+}
+
 #ifndef HAVE_NEPOMUK
 class KFileMetaDataWidget;
 #else
@@ -135,7 +141,7 @@ private:
 private:
     KFileItem m_item;
 
-    bool m_pendingPreview;
+    QPointer<KIO::PreviewJob> m_previewJob;
     QTimer* m_outdatedPreviewTimer;
 
     PixmapViewer* m_preview;
